# apicrud


## Description 
apicrud est une librairie python qui permet de générer de données et de se connecter aux api pour créer, lire, mettre à jour , supprimer,
s'authentifier et de se deconnecter.


#